/* wptCrypto.h
 *	Copyright (C) 2005 Timo Schulz
 *
 * This file is part of WinPT.
 *
 * WinPT is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * WinPT is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with WinPT; if not, write to the Free Software Foundation, 
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 */

#ifndef WPT_CRYPTO_H
#define WPT_CRYPTO_H

/* Available wipe modes. */
enum wipe_mode_t {
    WIPE_MODE_SIMPLE	= 0,	/* 2 random passes */
    WIPE_MODE_DOD	= 1,
    WIPE_MODE_GUTMANN	= 2,
    WIPE_MODE_FAST	= 3,	/* 1 random pass */
};



/* Possible PGP message types. */
enum pgp_type_t {
    PGP_NONE	     =  0,
    PGP_MESSAGE	     =  1,
    PGP_CLEARSIG     =  2,
    PGP_SIG	     =  4,
    PGP_PUBKEY	     =  8,
    PGP_SECKEY	     = 16,
    PGP_DASH_ESCAPED = 32 /* actually not a type, just a flag */
};


#ifdef __cplusplus
extern "C" {
#endif


int gpg_md_hash_file (int mdalgo, const char *file, byte *digest, size_t *nlen);
int gpg_md_selftest (void);




int rename_unlink (const char *path);
int secure_unlink (const char *path, const int mode);
void secure_unlink_set_cb (void (*cb)(void *, const char *, int, int, int),
			   void *cb_value);
int wipe_freespace (const char * drive, HANDLE *r_fd,
		    void (*cb)(void *, unsigned __int64, unsigned __int64), 
		    void * cb_value);

#ifdef __cplusplus
}
#endif


#endif /*WPT_CRYPTO_H*/

